@@ -165,4 +165,8 @@ class KicsTool(ToolGateway):
             finding_list = kics_deserealizator.get_list_finding(filtered_results)
 
             return finding_list, path_file
-        return [], None
\ No newline at end of file
+        return [], None
+    
+    def get_iac_context_from_results(self, path_file_results):
+        #TODO: Implement this method
+        pass
\ No newline at end of file
